pub struct CheckInfo {
pub api_key_uid: Option<String>,
pub consumer_info: Option<ConsumerInfo>,
pub ignore_api_key_uid_as_credential_id: Option<bool>,
pub unused_arguments: Option<Vec<String>>,
}Expand description
Contains additional information about the check operation.
This type is not used in any activity, and only used as part of another schema.
Fields
api_key_uid: Option<String>The unique id of the api key in the format of “apikey:”. This field will be populated when the consumer passed to Chemist is an API key and all the API key related validations are successful.
consumer_info: Option<ConsumerInfo>Consumer info of this check.
ignore_api_key_uid_as_credential_id: Option<bool>Whether or not the api key should be ignored in the credential_id during reporting.
unused_arguments: Option<Vec<String>>A list of fields and label keys that are ignored by the server. The client doesn’t need to send them for following requests to improve performance and allow better aggregation.