pub struct Distribution {
pub bucket_counts: Option<Vec<i64>>,
pub count: Option<i64>,
pub exemplars: Option<Vec<Exemplar>>,
pub explicit_buckets: Option<ExplicitBuckets>,
pub exponential_buckets: Option<ExponentialBuckets>,
pub linear_buckets: Option<LinearBuckets>,
pub maximum: Option<f64>,
pub mean: Option<f64>,
pub minimum: Option<f64>,
pub sum_of_squared_deviation: Option<f64>,
}Expand description
Distribution represents a frequency distribution of double-valued sample points. It contains the size of the population of sample points plus additional optional information: * the arithmetic mean of the samples * the minimum and maximum of the samples * the sum-squared-deviation of the samples, used to compute variance * a histogram of the values of the sample points
This type is not used in any activity, and only used as part of another schema.
Fields
bucket_counts: Option<Vec<i64>>The number of samples in each histogram bucket. bucket_counts are optional. If present, they must sum to the count value. The buckets are defined below in bucket_option. There are N buckets. bucket_counts[0] is the number of samples in the underflow bucket. bucket_counts[1] to bucket_counts[N-1] are the numbers of samples in each of the finite buckets. And bucket_counts[N] is the number of samples in the overflow bucket. See the comments of bucket_option below for more details. Any suffix of trailing zeros may be omitted.
count: Option<i64>The total number of samples in the distribution. Must be >= 0.
exemplars: Option<Vec<Exemplar>>Example points. Must be in increasing order of value field.
explicit_buckets: Option<ExplicitBuckets>Buckets with arbitrary user-provided width.
exponential_buckets: Option<ExponentialBuckets>Buckets with exponentially growing width.
linear_buckets: Option<LinearBuckets>Buckets with constant width.
maximum: Option<f64>The maximum of the population of values. Ignored if count is zero.
mean: Option<f64>The arithmetic mean of the samples in the distribution. If count is zero then this field must be zero.
minimum: Option<f64>The minimum of the population of values. Ignored if count is zero.
sum_of_squared_deviation: Option<f64>The sum of squared deviations from the mean: Sum[i=1..count]((x_i - mean)^2) where each x_i is a sample values. If count is zero then this field must be zero, otherwise validation of the request fails.