pub struct LinearBuckets {
pub num_finite_buckets: Option<i32>,
pub offset: Option<f64>,
pub width: Option<f64>,
}Expand description
Describing buckets with constant width.
This type is not used in any activity, and only used as part of another schema.
Fields
num_finite_buckets: Option<i32>The number of finite buckets. With the underflow and overflow buckets, the total number of buckets is num_finite_buckets + 2. See comments on bucket_options for details.
offset: Option<f64>The i’th linear bucket covers the interval [offset + (i-1) * width, offset + i * width) where i ranges from 1 to num_finite_buckets, inclusive.
width: Option<f64>The i’th linear bucket covers the interval [offset + (i-1) * width, offset + i * width) where i ranges from 1 to num_finite_buckets, inclusive. Must be strictly positive.