pub struct MetricValue {
pub bool_value: Option<bool>,
pub distribution_value: Option<Distribution>,
pub double_value: Option<f64>,
pub end_time: Option<DateTime<Utc>>,
pub int64_value: Option<i64>,
pub labels: Option<HashMap<String, String>>,
pub money_value: Option<Money>,
pub start_time: Option<DateTime<Utc>>,
pub string_value: Option<String>,
}Expand description
Represents a single metric value.
This type is not used in any activity, and only used as part of another schema.
Fields
bool_value: Option<bool>A boolean value.
distribution_value: Option<Distribution>A distribution value.
double_value: Option<f64>A double precision floating point value.
end_time: Option<DateTime<Utc>>The end of the time period over which this metric value’s measurement applies. If not specified, google.api.servicecontrol.v1.Operation.end_time will be used.
int64_value: Option<i64>A signed 64-bit integer value.
labels: Option<HashMap<String, String>>The labels describing the metric value. See comments on google.api.servicecontrol.v1.Operation.labels for the overriding relationship. Note that this map must not contain monitored resource labels.
money_value: Option<Money>A money value.
start_time: Option<DateTime<Utc>>The start of the time period over which this metric value’s measurement applies. The time period has different semantics for different metric types (cumulative, delta, and gauge). See the metric definition documentation in the service configuration for details. If not specified, google.api.servicecontrol.v1.Operation.start_time will be used.
string_value: Option<String>A text string value.