[][src]Struct google_servicecontrol1::CheckError

pub struct CheckError {
    pub status: Option<Status>,
    pub code: Option<String>,
    pub detail: Option<String>,
    pub subject: Option<String>,
}

Defines the errors to be returned in google.api.servicecontrol.v1.CheckResponse.check_errors.

This type is not used in any activity, and only used as part of another schema.

Fields

status: Option<Status>

Contains public information about the check error. If available, status.code will be non zero and client can propagate it out as public error.

code: Option<String>

The error code.

detail: Option<String>

Free-form text providing details on the error cause of the error.

subject: Option<String>

Subject to whom this error applies. See the specific code enum for more details on this field. For example:

  • “project:
  • “folder:
  • “organization: