[−][src]Struct google_servicecontrol1::CheckRequest
Request message for the Check method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- check services (request)
Fields
skip_activation_check: Option<bool>Indicates if service activation check should be skipped for this request. Default behavior is to perform the check and apply relevant quota. WARNING: Setting this flag to "true" will disable quota enforcement.
operation: Option<Operation>The operation to be checked.
service_config_id: Option<String>Specifies which version of service configuration should be used to process the request.
If unspecified or no matching version can be found, the latest one will be used.
request_project_settings: Option<bool>Requests the project settings to be returned as part of the check response.